@@ -25,12 +25,13 @@ called. After that changing it doesn't do anything anymore.
 
 """
 
-import utils
-import context
+from . import utils
+from . import context
 
 import itertools
 import functools
 import os
+import base64
 
 storageDir = "dbs"
 
@@ -54,13 +55,17 @@ class PouchDBError(Exception):
 
 	   try:
 	       ...
-	   except pouchdb.PouchDBError, e:
+	   except pouchdb.PouchDBError as e:
 	       if e["status"] == 404:
 	           print "Not found"
 	       else:
 	           print "Unknown error"
 
 	"""
+	def __init__(self, message, *args, **kwargs):
+		super(PouchDBError, self).__init__(*args, **kwargs)
+
+		self.message = message
 
 	def __getitem__(self, key):
 		return self.message[key]
@@ -178,7 +183,7 @@ class PouchDB(object):
 				doc["_attachments"] = {}
 			doc["_attachments"][attachmentId] = {
 				"content_type": type,
-				"data": attachmentBytes.encode("base64").strip(),
+				"data": base64.b64encode(attachmentBytes).decode("ascii"),
 			}
 			return self.put(doc, callback)
 
@@ -187,16 +192,16 @@ class PouchDB(object):
 		else:
 			try:
 				resp = self.get(docId, rev=rev)
-			except PouchDBError, e:
+			except PouchDBError as e:
 				resp = None
-				err = e.message
+				err = e
 			else:
 				err = None
 			return getCallback(err, resp)
 
 	def getAttachment(self, docId, attachmentId, callback=None, **options):
 		def modifyAttachment(attachment):
-			attachment["data"] = str(attachment["data"]).decode("base64")
+			attachment["data"] = base64.b64decode(attachment["data"])
 			return attachment
 
 		def getAttachmentCallback(err, attachment=None):
