@@ -7,7 +7,7 @@ import sys
 import os
 import json
 
-import utils
+from . import utils
 
 class Page(QtWebKit.QWebPage):
 	def __init__(self, gate, *args, **kwargs):
