@@ -1,4 +1,6 @@
-import __init__ as pouchdb
+# coding=UTF-8
+
+import pouchdb
 import unittest
 import urllib2
 
@@ -24,7 +26,7 @@ class PouchDBTestCaseWithDBAndAttachment(PouchDBTestCaseWithDB):
 	def setUp(self):
 		super(PouchDBTestCaseWithDBAndAttachment, self).setUp()
 
-		resp = self._db.putAttachment("attachment_test", "text", "abcd", "text/plain")
+		resp = self._db.putAttachment("attachment_test", "text", b"abcd", "text/plain")
 		self.rev = resp["rev"]
 
 class AllDbsTests(PouchDBTestCase):
@@ -157,13 +159,13 @@ class RevsDiffTests(PouchDBTestCaseWithDB):
 
 class PutAttachmentTests(PouchDBTestCaseWithDB):
 	def testSimplePutAttachment(self):
-		resp = self._db.putAttachment("attachment_test", "text", "abcd", "text/plain")
+		resp = self._db.putAttachment("attachment_test", "text", b"abcd", "text/plain")
 		self.assertTrue(resp["ok"])
 
 	def testPutTwoAttachmentsInSameDoc(self):
-		resp = self._db.putAttachment("attachment_test", "text", "abcd", "text/plain")
+		resp = self._db.putAttachment("attachment_test", "text", b"abcd", "text/plain")
 		rev = resp["rev"]
-		resp2 = self._db.putAttachment("attachment_test", "text2", "efgh", "text/plain", rev)
+		resp2 = self._db.putAttachment("attachment_test", "text2", u"éfgh".encode("UTF-8"), "text/plain", rev)
 		self.assertTrue(resp2["ok"])
 
 	def testPutAttachmentAsync(self):
@@ -172,14 +174,14 @@ class PutAttachmentTests(PouchDBTestCaseWithDB):
 			result["err"] = err
 			result["resp"] = resp
 
-		self._db.putAttachment("attachment_test", "text", "abcd", "text/plain", callback=putAttachmentCallback)
+		self._db.putAttachment("attachment_test", "text", b"abcd", "text/plain", callback=putAttachmentCallback)
 		pouchdb.getContext().waitUntilCalled(putAttachmentCallback)
 		self.assertTrue(result["resp"]["ok"])
 
 class GetAttachmentTests(PouchDBTestCaseWithDBAndAttachment):
 	def testSimpleGetAttachment(self):
 		resp = self._db.getAttachment("attachment_test", "text")
-		self.assertEqual(resp["data"], "abcd")
+		self.assertEqual(resp["data"], b"abcd")
 
 	def testGetAttachmentAsync(self):
 		result = {}
@@ -188,7 +190,7 @@ class GetAttachmentTests(PouchDBTestCaseWithDBAndAttachment):
 			result["resp"] = resp
 		self._db.getAttachment("attachment_test", "text", callback)
 		pouchdb.getContext().waitUntilCalled(callback)
-		self.assertEqual(result["resp"]["data"], "abcd")
+		self.assertEqual(result["resp"]["data"], b"abcd")
 
 	def testMissingDoc(self):
 		with self.assertRaises(pouchdb.PouchDBError) as cm:
@@ -345,14 +347,14 @@ class HttpTests(unittest.TestCase):
 		self.assertIn("db_name", self._db.info())
 
 	def testAttachment(self):
-		rev = self._db.putAttachment("attachment-doc", "attachment", "<h1>Hello World!</h1>", "text/html")["rev"]
+		rev = self._db.putAttachment("attachment-doc", "attachment", b"<h1>Hello World!</h1>", "text/html")["rev"]
 
 		resp = urllib2.urlopen(COUCHDB_HOST + "/test/attachment-doc/attachment")
-		self.assertEqual(resp.read(), "<h1>Hello World!</h1>")
+		self.assertEqual(resp.read(), b"<h1>Hello World!</h1>")
 		self.assertEqual(resp.info()["Content-Type"], "text/html")
 
 		a = self._db.getAttachment("attachment-doc", "attachment")
-		self.assertEqual(a["data"], "<h1>Hello World!</h1>")
+		self.assertEqual(a["data"], b"<h1>Hello World!</h1>")
 		self.assertEqual(a["type"], "text/html")
 
 		self._db.removeAttachment("attachment-doc", "attachment", rev)
@@ -366,8 +368,3 @@ class HttpTests(unittest.TestCase):
 
 	def tearDown(self):
 		pouchdb.PouchDB.destroy(COUCHDB_HOST + "/test")
-
-if __name__ == "__main__":#pragma: no branch
-	#just in case there are any leftovers from, say, manual tests.
-	cleanup()
-	unittest.main()
